@@ -1,16 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from api import Api, EverysportException
-import results
-
-'''Teams from everysport.com
+'''A Python wrapper for the Everysport API
 '''
 
-from teams import Team 
+from api import Api, EverysportException
+
+
+from commons import Team 
 
 MFF = Team(9375,u"Malmö FF", "", "")
-HBG = Team(9373,u"Helingsborgs IF", "", "")
+HIF = Team(9373,u"Helingsborgs IF", "", "")
 LSD = Team(1175,u"Leksand", "", "")
 CHI = Team(28075,u"Chicago Blackhawks", "", "")
 
